@@ -1,19 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import os, errno
-import re
-import sys
-import time
-import datetime
-import gzip
-import glob
-from datetime import datetime
-from pprint import pprint
-
 from optparse import make_option
-from django.core.management.base import BaseCommand, CommandError
-from django.template.defaultfilters import slugify
+from django.core.management.base import BaseCommand
 from django.template import Context, Template
 from django.conf import settings as conf
 from sorl.thumbnail import get_thumbnail
@@ -41,14 +30,22 @@ class Command(BaseCommand):
 
     To run this script from a crontab task we should do something like this:
 
-    */30 * * * * cd /path/to/rgallery-project/ ; source env/bin/activate ; cd src ; python manage.py mediasync > /dev/null
+    */30 * * * * cd /path/to/rgallery-project/ ; source env/bin/activate ; \
+                 cd src ; python manage.py mediasync > /dev/null
 
     Options:
         --storage=[dropbox|file]
         --source=/path/to/photos (only when storage=file)
+        --tags=peques,tag2,tag3
 
     """
 
+    # If there is a HOMETAG, set is as the default tag importing photos
+    try:
+        default_tag = conf.HOMETAG
+    except:
+        default_tag = None
+
     option_list = BaseCommand.option_list + (
         make_option(
             '--storage',
@@ -62,6 +59,12 @@ class Command(BaseCommand):
             default='/Users/oscar/Desktop/Peques/',
             help='Where the photos are in --storage=file'
         ),
+        make_option(
+            '--tags',
+            dest='tags',
+            default=default_tag,
+            help='Tag(s) to add to photos --tag=tag1,tag2,tag3'
+        ),
     )
 
     def handle(self, *app_labels, **options):
@@ -72,6 +75,10 @@ class Command(BaseCommand):
         # Vars and folders
         storage = options['storage']
         source = options['source']
+        try:
+            tags = [x.strip() for x in options['tags'].split(',')]
+        except:
+            tags = ''
         img_duped = 0
         vid_duped = 0
         img_total = 0
@@ -79,11 +86,22 @@ class Command(BaseCommand):
         total = 0
         thumbs = conf.RGALLLERY_THUMBS
 
+        # print "*"*80
+        # print tags
+        # print len(tags)
+        # print "*"*80
+        # exit(0)
+
         # Handle connection with the backend (dinamically importing backend)
         # backend_file, backend_dropbox...
-        backend = __import__('rgallery.management.commands.backend_%s' % storage, fromlist='*')
+        backend = __import__(
+            'rgallery.management.commands.backend_%s' % storage,
+            fromlist='*')
 
         print "-"*80
+        if options['tags']:
+                print "[WWW] Photos are being imported with [%s] tags..." % \
+                    options['tags']
         print "[***] Importing..."
         print ""
 
@@ -106,7 +124,8 @@ class Command(BaseCommand):
                 vid_duped,
                 img_total,
                 vid_total,
-                total)
+                total,
+                tags)
 
         print ""
         print "-"*80
@@ -115,7 +134,7 @@ class Command(BaseCommand):
         print ""
         conf.THUMBNAIL_DEBUG = True
         allphotos = mymodels.Photo.objects.all()
-        for i,p in enumerate(allphotos):
+        for i, p in enumerate(allphotos):
             print "%04d - %s" % (i, p)
             for thumb in thumbs:
                 c = Context({'image': p, 'thumb': "%sx%s" % (thumb, thumb)})
