@@ -182,7 +182,8 @@ def video_convert(video, file, srcdir, destdir, video_name, rotate):
 # MEDIASYNC ********************************************************************
 
 def mediasync(file, srcdir, photodestdir, videodestdir, thumbs, backend,
-              client, img_duped, vid_duped, img_total, vid_total, total, tags):
+              client, img_duped, vid_duped, img_total, vid_total, total,
+              tags=''):
 
     filename = os.path.basename(backend.filepath(file))
     if backend.is_image(file):
