@@ -192,7 +192,8 @@ class PhotoAdd(LoginRequiredMixin, SuperuserRequiredMixin, CreateView):
             0,
             0,
             0,
-            0)
+            0,
+            '')
 
         expire_view_cache("app_gallery-gallery")
         return HttpResponseRedirect(self.get_success_url())
